# 2023.01.0

**Released on January 17th, 2023**

[Documentation for this release](https://cotainr.readthedocs.org/en/2023.01.0/)

Minor release to fix an issue.

## Bug fixes

- Fixed a bug with `umask`, which could lead to permission problems with `conda` installation.
